@@ -1,7 +1,9 @@
 #!/usr/bin/env bash
-PIDFILE="$PWD/logs/gunicorn.pid"
+PIDFILE="$PWD/gunicorn.pid"
 
 if [ -f $PIDFILE ]; then
     PID=$(cat $PIDFILE)
     kill -9 $PID
+    rm $PIDFILE
+    echo 'over'
 fi
\ No newline at end of file
